summaryrefslogtreecommitdiff
path: root/framework/Web/UI/WebControls/TCheckBox.php
diff options
context:
space:
mode:
authorxue <>2006-01-21 17:29:40 +0000
committerxue <>2006-01-21 17:29:40 +0000
commit3fcf847e0cadfb9ede930f538c2f277483442175 (patch)
tree12534cf4b29c1d4676fd59ab47adb60e292bcb6c /framework/Web/UI/WebControls/TCheckBox.php
parent99b56c855a597c606d349c7063d843539e65a6ed (diff)
BE AWARE: Significant change!
Changed event definition from XXX to OnXXX.
Diffstat (limited to 'framework/Web/UI/WebControls/TCheckBox.php')
-rw-r--r--framework/Web/UI/WebControls/TCheckBox.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/framework/Web/UI/WebControls/TCheckBox.php b/framework/Web/UI/WebControls/TCheckBox.php
index 385eca06..ae6dc8e4 100644
--- a/framework/Web/UI/WebControls/TCheckBox.php
+++ b/framework/Web/UI/WebControls/TCheckBox.php
@@ -20,10 +20,10 @@
* property.
*
* To determine whether the TCheckBox component is checked, test the {@link getChecked Checked}
- * property. The {@link onCheckedChanged CheckedChanged} event is raised when
+ * property. The {@link onCheckedChanged OnCheckedChanged} event is raised when
* the {@link getChecked Checked} state of the TCheckBox component changes
* between posts to the server. You can provide an event handler for
- * the {@link onCheckedChanged CheckedChanged} event to to programmatically
+ * the {@link onCheckedChanged OnCheckedChanged} event to to programmatically
* control the actions performed when the state of the TCheckBox component changes
* between posts to the server.
*
@@ -71,7 +71,7 @@ class TCheckBox extends TWebControl implements IPostBackDataHandler, IValidatabl
/**
* Raises postdata changed event.
- * This method raises {@link onCheckedChanged CheckedChanged} event.
+ * This method raises {@link onCheckedChanged OnCheckedChanged} event.
* This method is primarly used by framework developers.
*/
public function raisePostDataChangedEvent()
@@ -87,14 +87,14 @@ class TCheckBox extends TWebControl implements IPostBackDataHandler, IValidatabl
}
/**
* Raises <b>CheckedChanged</b> event when {@link getChecked Checked} changes value during postback.
* If you override this method, be sure to call the parent implementation
* so that the event delegates can be invoked.
* @param TEventParameter event parameter to be passed to the event handlers
*/
protected function onCheckedChanged($param)
{
- $this->raiseEvent('CheckedChanged',$this,$param);
+ $this->raiseEvent('OnCheckedChanged',$this,$param);
}
/**
@@ -87,14 +87,14 @@ class TCheckBox extends TWebControl implements IPostBackDataHandler, IValidatabl
}
/**
- * Raises <b>CheckedChanged</b> event when {@link getChecked Checked} changes value during postback.
+ * Raises <b>OnCheckedChanged</b> event when {@link getChecked Checked} changes value during postback.
* If you override this method, be sure to call the parent implementation
* so that the event delegates can be invoked.